#/bin/sh

CHAP=5
APPNAME=gcc
APPVER=.2
VER=5.2.0
TARGET=gcc-$VER
TARGETBALL=$TARGET.tar.bz2
TARGETDIR=$TARGET

VER_mpfr=3.1.3
VER_gmp=6.0.0
VER_gmp2=${VER_gmp}a
VER_mpc=1.0.3

. ./_lfsset.sh

cd $SRC

echo $TARGET

echo \ \ Removing old directory...
rm -fr $TARGETDIR
rm -fr gcc-build

. $WRK/_extract.sh

cd $TARGETDIR

tar -Jxf $DLD/mpfr-$VER_mpfr.tar.xz || exit 1
mv mpfr-$VER_mpfr mpfr
tar -Jxf $DLD/gmp-$VER_gmp2.tar.xz || exit 1
mv gmp-$VER_gmp gmp
tar -zxf $DLD/mpc-$VER_mpc.tar.gz || exit 1
mv mpc-$VER_mpc mpc

TimeStart

for file in \
 $(find gcc/config -name linux64.h -o -name linux.h -o -name sysv4.h)
do
  cp -uv $file{,.orig} \
	1> $LOG/$CHAP.$TARGET.0_copy.log 2>&1 || exit 1
  sed -e 's@/lib\(64\)\?\(32\)\?/ld@/tools&@g' \
      -e 's@/usr@/tools@g' $file.orig > $file
  echo '
#undef STANDARD_STARTFILE_PREFIX_1
#undef STANDARD_STARTFILE_PREFIX_2
#define STANDARD_STARTFILE_PREFIX_1 "/tools/lib/"
#define STANDARD_STARTFILE_PREFIX_2 ""' >> $file
  touch $file.orig
done

mkdir ../gcc-build
cd ../gcc-build

echo \ \ Configuring...
../gcc-$VER/configure                              \
    --target=$LFS_TGT                              \
    --prefix=/tools                                \
    --with-glibc-version=2.11                      \
    --with-sysroot=$LFS                            \
    --with-newlib                                  \
    --without-headers                              \
    --with-local-prefix=/tools                     \
    --with-native-system-header-dir=/tools/include \
    --disable-nls                                  \
    --disable-shared                               \
    --disable-multilib                             \
    --disable-decimal-float                        \
    --disable-threads                              \
    --disable-libatomic                            \
    --disable-libgomp                              \
    --disable-libquadmath                          \
    --disable-libssp                               \
    --disable-libvtv                               \
    --disable-libstdcxx                            \
    --enable-languages=c,c++                       \
	1> $LOG/$CHAP.$TARGET.1_conf.log 2>&1 || exit 1

echo \ \ Making...
make \
	1> $LOG/$CHAP.$TARGET.2_make.log 2>&1 || exit 1

echo \ \ Installing...
make install \
	1> $LOG/$CHAP.$TARGET.3_install.log 2>&1 || exit 1

TimeEnd chap5

echo \ \ Removing directory...
cd ..
rm -fr $TARGETDIR
rm -fr gcc-build

echo \ \ Done.

